==> sdd.mercadopago-0.1.6-sources.jar: ar/com/sdd/mercadopago/resources/datastructures/preference/Item.java <==
package ar.com.sdd.mercadopago.resources.datastructures.preference;

import ar.com.sdd.mercadopago.core.annotations.validation.NotNull;
import ar.com.sdd.mercadopago.core.annotations.validation.Numeric;
import ar.com.sdd.mercadopago.core.annotations.validation.Size;

/**
 * Mercado Pago MercadoPago
 * Preference Item class
 *
 * Created by Eduardo Paoletta on 12/2/16.
 */
public class Item {

    @Size(max=256) private String id = null;
    @Size(max=256) private String title = null;
    @Size(max=256) private String description = null;
    @Size(max=600) private String pictureUrl = null;
    @Size(max=256) private String categoryId = null;
    @NotNull @Numeric(min=1) private Integer quantity = null;
    @Size(min=3, max=3) private String currencyId = null;
    @NotNull @Numeric(min=.01f, max=999999f, fractionDigits=2) private Float unitPrice = 0f;


    public String getId() {
        return id;
    }

    public Item setId(String id) {
        this.id = id;
        return this;
    }

    public String getTitle() {
        return title;
    }

    public Item setTitle(String title) {
        this.title = title;
        return this;
    }

    public String getDescription() {
        return description;
    }

    public Item setDescription(String description) {
        this.description = description;
        return this;
    }

    public String getPictureUrl() {
        return pictureUrl;
    }

    public Item setPictureUrl(String pictureUrl) {
        this.pictureUrl = pictureUrl;
        return this;
    }

    public String getCategoryId() {
        return categoryId;
    }

    public Item setCategoryId(String categoryId) {
        this.categoryId = categoryId;
        return this;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public Item setQuantity(Integer quantity) {
        this.quantity = quantity;
        return this;
    }

    public String getCurrencyId() {
        return currencyId;
    }

    public Item setCurrencyId(String currencyId) {
        this.currencyId = currencyId;
        return this;
    }

    public Float getUnitPrice() {
        return unitPrice;
    }

    public Item setUnitPrice(Float unitPrice) {
        this.unitPrice = unitPrice;
        return this;
    }

}

==> sdd.mercadopago-0.1.14-sources.jar: ar/com/sdd/mercadopago/resources/datastructures/preference/Item.java <==
package ar.com.sdd.mercadopago.resources.datastructures.preference;

import ar.com.sdd.mercadopago.core.annotations.validation.NotNull;
import ar.com.sdd.mercadopago.core.annotations.validation.Numeric;
import ar.com.sdd.mercadopago.core.annotations.validation.Size;

import java.math.BigDecimal;

/**
 * Mercado Pago MercadoPago
 * Preference Item class
 *
 * Created by Eduardo Paoletta on 12/2/16.
 */
public class Item {

    @Size(max=256) private String id = null;
    @Size(max=256) private String title = null;
    @Size(max=256) private String description = null;
    @Size(max=600) private String pictureUrl = null;
    @Size(max=256) private String categoryId = null;
    @NotNull @Numeric(min=1) private Integer quantity = null;
    @Size(min=3, max=3) private String currencyId = null;
    @NotNull @Numeric private BigDecimal unitPrice = new BigDecimal(0);


    public String getId() {
        return id;
    }

    public Item setId(String id) {
        this.id = id;
        return this;
    }

    public String getTitle() {
        return title;
    }

    public Item setTitle(String title) {
        this.title = title;
        return this;
    }

    public String getDescription() {
        return description;
    }

    public Item setDescription(String description) {
        this.description = description;
        return this;
    }

    public String getPictureUrl() {
        return pictureUrl;
    }

    public Item setPictureUrl(String pictureUrl) {
        this.pictureUrl = pictureUrl;
        return this;
    }

    public String getCategoryId() {
        return categoryId;
    }

    public Item setCategoryId(String categoryId) {
        this.categoryId = categoryId;
        return this;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public Item setQuantity(Integer quantity) {
        this.quantity = quantity;
        return this;
    }

    public String getCurrencyId() {
        return currencyId;
    }

    public Item setCurrencyId(String currencyId) {
        this.currencyId = currencyId;
        return this;
    }

    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public Item setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
        return this;
    }

}
